********************************************************
*
* MSS_12_188_Using_Cash_to_Monitor_Liquidity_STATA_ANALYSIS.do
*
* This file conducts the analysis and generates the tables 
* for von Kalckreuth et al. "Using Cash to Monitor Liquidity  Implications for Payments, Currency Demand and Withdrawal Behavior"
*
* Note: only owners of debit cards are included in the sample
*
* Download mat2txt and outreg2 if you want the file to output results in txt- and excel-files
*
* Database: MSS_12_188_Using_Cash_to_Monitor_Liquidity_DATA.csv  
*
* This version: November 18, 2013 
*
********************************************************

* Settings
* ========

clear all
clear matrix
set more off
set mem 450m
set maxvar 10000
cap log close
window manage maintitle "von Kalckreuth et al. - Using Cash to Monitor Liquidity"

* set working directory  
	
	global path "R:\Zentrale\6\Daten\6_Datenaustausch\Schmidt_Eschelbach\JMCB"
	cd "$path"
	

* OPEN LOG FILE
* =============

		cap log close
		log using "$path\log\LOG_von_Kalkreuth_Schmidt_Stix.txt", replace text
	
	
* Read in Data
* ============

	insheet age age2 male education edu_m_high_uni EDU_LOW EDU_MEDIUM EDU_HIGH EDU_UNI pinc_mitte HH_INC employed unemployed other retired bik_07 bik_1 bik_2 bik_3 bik_4 bik_5 bik_6 bik_7 risk_theft NUM_DIFF_PI P_EXPCONTR_CASH IA2_EXPC_LENGTH ausgaben ausgaben_length2 sec_pro_quest CASHP_ALL CASHP_MAINLOC CASHP_B100 SHARE_CASH_TRANS SHARE_CASH_VALUE THRESH_CARD DIST_WITHDR fees ATM_USER AVGWITHDAM lnAVGWITHDAM thresh_nextwithdr lnamount withdraw_frq_unscaled anteil_barvol_gesamt AVG_VAL_TRANS sectoral_trans_1 sectoral_trans_2 sectoral_trans_3 sectoral_trans_4 sectoral_trans_5 sectoral_trans_6 sectoral_trans_7 sectoral_trans_8 sectoral_trans_9 P_ANONYM_CASH P_HABIT_CASH schwelle_kplus2a schwelle_kplus2b using "$path\data\MSS_12_188_Using_Cash_to_Monitor_Liquidity_DATA.csv", comma clear
		
	* list of variables - for a detailed description of the construction of the variables see Appendix A of the paper
	*----------------------------------------------------------------------------------------------------------------
	
	* a) Table A1 List of Payment Variables to Test the Hypotheses
	
		* CASHP_ALL - Person always pays cash
	
			rename cashp_all CASHP_ALL 
			
		* CASHP_MAINLOC - Person pays cash: retail, gas stations and for services consumed outside home	
			
			rename cashp_mainloc CASHP_MAINLOC
			
		* CASHP_B100 - Person pays cash up to 100 euro	
			
			rename cashp_b100 CASHP_B100
			
		* SHARE_CASH_TRANS - Percentage of cash transactions (volume)	
		
			rename share_cash_trans SHARE_CASH_TRANS
			
		* SHARE_CASH_VALUE  - Percentage of cash transactions (value)
		
		    rename share_cash_value	SHARE_CASH_VALUE 
			
		* THRESH_CARD - Euro amount at which the person starts paying by card
		
			rename thresh_card THRESH_CARD
			
			* schwelle_kplus2a schwelle_kplus2b - auxilliary variables used in the intervall regression, for threshold at which person starts paying with to use cards
			
		* NUM_DIFF_PI - Number of different payment instruments in use	
	
			rename num_diff_pi NUM_DIFF_PI
			
		* withdraw_frq_unscaled - Average number of withdrawals per month
		
		* lnAVGWITHDAM - Average amount withdrawn at each withdrawal
		
		   rename avgwithdam AVGWITHDAM
		   rename lnavgwithdam lnAVGWITHDAM
		   
	* b) table A2 - List of Variables to Separate Restricted and Unrestricted Consumers
		
		* P_EXPCONTR_CASH - pocket watcher
		
			rename p_expcontr_cash P_EXPCONTR_CASH 
				
		* ausgaben - need to monitor
		
		* sec_pro_quest - Interview length  
				
		* ausgaben_length2 - Need to monitor and long interview versus need to monitor and short interview / No need to monitor and long interview 

		* IA2_EXPC_LENGTH - dummy variable, value = 0 (!) if consumer needs to control expenditures and has long interview
		
			rename ia2_expc_length IA2_EXPC_LENGTH 
		
	* c) Table A3 List of Variables Included as Control Variables in the reduced form estimations
	
		* lnamount - Total amount withdrawn per month
		
		* Distance to next ATM / bank desk
		
			rename dist_withdr DIST_WITHDR 
		
		* fees - Fees
		
		* ATM_USER - ATM User
		
			rename atm_user ATM_USER
		
		* HH_INC - Household monthly income
		   
		   rename hh_inc HH_INC
		   
		* risk_theft - Risk theft 
		
		* AVG_VAL_TRANS - Average transactions value
		
			rename avg_val_trans AVG_VAL_TRANS
			
		* Anonymity important and only cash fulfils it
		   
			rename p_anonym_cash P_ANONYM_CASH 
			
		* Familiarity important and only cash fulfils it	
			
			rename p_habit_cash P_HABIT_CASH
			
		* sectoral_trans_1 - sectoral_trans_9 Share of transactions at location X in all transactions	
			
	* d) Socio-demo. and Regional Indicators
	
		* age age of respondent 
		* age2 age of respondent, squared  
	
		* edu_m_high_uni - Education high - 
		* EDU_LOW EDU_MEDIUM EDU_HIGH EDU_UNI - additional indicators for education of respondent
		
				rename edu_low 	  EDU_LOW 
				rename edu_medium EDU_MEDIUM 
				rename edu_high   EDU_HIGH 
				rename edu_uni    EDU_UNI
	
		* pinc_mitte - Personal monthly income  
		
		* employed unemployed retired other - employment status 
	
		* bik_07, bik_1 bik_2 bik_3 bik_4 bik_5 bik_6 bik_7 - size of municipality 
			 
	* e) Other indicators used to calculate descriptives, figures in the text
	 
		* anteil_barvol_gesamt - Cash share in terms of value
		
		* thresh_nextwithdr - Threshold of cash in the pocket before next withdrawal (Scale: Amount in Pocket)
	
		
* Do Analysis
* ===========	

* Descriptive Statistics 1 - figures used in various parts of the paper
* ----------------------------------------------------------------------
	
* Introduction - Cash share in terms of value for highly educated individuals, between 35 and 45, in larg cities, with a debit card
 
	sum anteil_barvol_gesamt if (EDU_HIGH==1 | EDU_MEDIUM==1 | EDU_UNI==1) & (age>=35 & age<=45) & (bik_07==5 | bik_07==6 | bik_07==7) 

* Section 3.3 - Interview length

	sum sec_pro_quest
	
* Section 3.3 - Restricted	consumers, need to monitor, both

	tab IA2_EXPC_LENGTH, miss
	

* Table 2 - Mean comparison between restricted and unrestricted consumers
* ----------------------------------------------------------------------- 

	cap prog drop table_means
	prog def table_means

	 local sep `1'
	 local full `2'

	qui{

		local testvar	"CASHP_ALL CASHP_MAINLOC CASHP_B100 SHARE_CASH_TRANS SHARE_CASH_VALUE THRESH_CARD NUM_DIFF_PI AVGWITHDAM withdraw_frq_unscaled"

		tabstat  `testvar' , by (`sep') s(mean) varwidth(40) labelwidth(40) save

		* Add tests and p-values

		matrix B=(r(Stat1) \ r(Stat2))
		matrix H=(0,0,0,0,0,0,0,0,0)
		matrix C=(B\H\H)
		qui: prtest CASHP_ALL, by(`sep')
		matrix C[3,1]=r(z)
		matrix C[4,1]=2*(1-normal(abs(r(z))))
		qui: prtest CASHP_MAINLOC, by(`sep') 
		matrix C[3,2]=r(z)
		matrix C[4,2]=2*(1-normal(abs(r(z))))
		qui: prtest CASHP_B100 , by(`sep')
		matrix C[3,3]=r(z)
		matrix C[4,3]=2*(1-normal(abs(r(z))))
		qui: ttest SHARE_CASH_TRANS, by(`sep') uneq
		matrix C[3,4]=r(t)
		matrix C[4,4]=r(p)
		qui: ttest SHARE_CASH_VALUE, by(`sep') uneq
		matrix C[3,5]=r(t)
		matrix C[4,5]=r(p)
		qui: ttest THRESH_CARD, by(`sep') uneq
		matrix C[3,6]=r(t)
		matrix C[4,6]=r(p)
		qui: ttest NUM_DIFF_PI, by(`sep')
		matrix C[3,7]=r(t)
		matrix C[4,7]=r(p)
		qui: ttest AVGWITHDAM, by(`sep') uneq
		matrix C[3,8]=r(t)
		matrix C[4,8]=r(p)
		qui: ttest withdraw_frq_unscaled, by(`sep') uneq
		matrix C[3,9]=r(t)
		matrix C[4,9]=r(p)
		
		matname C Tval_Zval, row(3) explicit
		matname C p_val, row(4) explicit
	}

	matrix list C
	matrix Q=C'
	matrix list Q

	cd "$path\results"

	* download mat2txt if you want to send the martix to a txt-File
	* mat2txt , matrix(Q) saving(matrix`sep'_`full'.txt) replace

	clear matrix

	end

* start program for pocket watchers and restricted consumers

	for varlist P_EXPCONTR_CASH IA2_EXPC_LENGTH: table_means X F

log close
log using "$path\results\Table3_von_Kalkreuth_Schmidt_Stix.txt", replace text
	
	
* Table 3 - Mean Comparison Pocket Watchers and restricted consumers
* ------------------------------------------------------------------

	* Column 1 - Total

		tabstat pinc_mitte age male EDU_LOW EDU_MEDIUM EDU_HIGH EDU_UNI employed unemployed retired , s(mean sd n) col(stat)	
	
	* Characteristics of pocket watchers
 
		tabstat pinc_mitte age male EDU_LOW EDU_MEDIUM EDU_HIGH EDU_UNI employed unemployed retired if P_EXPCONTR_CASH==1, s(mean sd n) col(stat)
	
	* Characteristics of restricted individuals 
 
		tabstat pinc_mitte age male EDU_LOW EDU_MEDIUM EDU_HIGH EDU_UNI employed unemployed retired if IA2_EXPC_LENGTH==0,  s(mean sd n) col(stat)
 
 
log close
 
log using "$path\log\LOG_von_Kalkreuth_Schmidt_Stix.txt", append text
 
 
* Table 4 and 6 - Reduced for Regression - Pocket Watchers / Restricted 
* ----------------------------------------------------------------------

	*EXTREMWERTE BEI AVG_VAL_TRANS?
	
	sum AVG_VAL_TRANS, d

* Independent Variables
	
		global lna "DIST_WITHDR HH_INC risk_theft fees ATM_USER AVG_VAL_TRANS edu_m_high_uni age age2 P_ANONYM_CASH P_HABIT_CASH sectoral_trans_2 - sectoral_trans_9 bik_2-bik_7"

* Probit	
	
cap prog drop probits
prog def probits	
	
	local abh `1'
 	
	xi: dprobit `abh' P_EXPCONTR_CASH $lna  if AVG_VAL_TRANS<3 , robust	

	* outreg2 using "$path\results\regressions_Tab4_`abh'.xls", replace bracket tdec(3) bdec(3)

	xi: dprobit `abh' i.ausgaben_length2 $lna    if AVG_VAL_TRANS<3, robust
	
	* outreg2 using "$path\results\regressions_Tab6_`abh'.xls", replace bracket tdec(3) bdec(3)
	
end
      

	  for varlist CASHP_ALL CASHP_MAINLOC CASHP_B100: probits X 

* OLS 1	   
	  
cap prog drop regressions
prog def regressions
	
	local abh `1'
	
	xi: regress `abh' P_EXPCONTR_CASH $lna   if AVG_VAL_TRANS<3 , robust	

	* outreg2 using "$path\results\regressions_Tab4_`abh'.xls", replace bracket tdec(3) bdec(3)

	xi: regress `abh'  i.ausgaben_length2 $lna    if AVG_VAL_TRANS<3, robust
	
	* outreg2 using "$path\results\regressions_Tab6_`abh'.xls", replace bracket tdec(3) bdec(3)
	
	
end

	for varlist SHARE_CASH_TRANS SHARE_CASH_VALUE : regressions X 

	
* Ordered Probit	
	
cap prog drop oprobits
prog def oprobits

	local abh `1'
 
	xi: oprobit `abh' P_EXPCONTR_CASH $lna   if AVG_VAL_TRANS<3 , robust	

	* outreg2 using "$path\results\regressions_Tab4_`abh'.xls", replace bracket tdec(3) bdec(3)

	xi: oprobit `abh'  i.ausgaben_length2 $lna    if AVG_VAL_TRANS<3, robust
	
	* outreg2 using "$path\results\regressions_Tab6_`abh'.xls", replace bracket tdec(3) bdec(3)
	
end	  
 
	  for varlist NUM_DIFF_PI: oprobits X 	
	
* Intervall
 
cap prog drop intregs
prog def intregs
 
	local abh1 `1'
	local abh2 `2'

	xi: intreg `abh1' `abh2' P_EXPCONTR_CASH $lna   if AVG_VAL_TRANS<3 , robust

	* outreg2 using "$path\results\regressions_Tab4_start_card.xls", replace bracket tdec(3) bdec(3)

	xi: intreg `abh1' `abh2'  i.ausgaben_length2 $lna    if AVG_VAL_TRANS<3, robust
	
	* outreg2 using "$path\results\regressions_Tab6_start_card.xls", replace bracket tdec(3) bdec(3)
	
end	  
	  
	intregs schwelle_kplus2a schwelle_kplus2b 

* OLS 2

	global lna "lnamount DIST_WITHDR HH_INC risk_theft fees edu_m_high_uni age age2 bik_2-bik_7" 
	
	regressions lnAVGWITHDAM 
	
	  
  
* Table 5 - Reduced Form Regressions - POCKET WATCHER
* ---------------------------------------------------
 
	xi: dprobit P_EXPCONTR_CASH sec_pro_quest ausgaben age age2 i.education pinc_mitte, robust
	
	*outreg2 using "$path\results\regressions_Tab5.xls", replace bracket tdec(3) bdec(3) 
  
* Table 6 - See above
*----------------------  
  
log close
log using "$path\results\Table7_von_Kalkreuth_Schmidt_Stix.txt", replace text  
  
* Table 7 Correlation Structure
* -----------------------------

	local testvar="SHARE_CASH_TRANS SHARE_CASH_VALUE withdraw_frq_unscaled THRESH_CARD NUM_DIFF_PI"
 
	pwcorr `testvar',  bonferroni 			 star(0.10)

  
log close
exit








































 
